@@ -6,10 +6,11 @@ use strict;
 use HTML::Parser 3.20;
 use HTML::Tagset 3.03;
 
+use HTML::Lint::Error ();
 use HTML::Lint::HTML4 qw( %isKnownAttribute %isRequired %isNonrepeatable %isObsolete );
 use HTML::Entities qw( %char2entity %entity2char );
 
-use base 'HTML::Parser';
+use parent 'HTML::Parser';
 
 =head1 NAME
 
@@ -17,11 +18,11 @@ HTML::Lint::Parser - Parser for HTML::Lint.  No user-serviceable parts inside.
 
 =head1 VERSION
 
-Version 2.27_01
+Version 2.27_02
 
 =cut
 
-our $VERSION = '2.27_01';
+our $VERSION = '2.27_02';
 
 =head1 SYNOPSIS
 
@@ -165,6 +166,8 @@ sub _text {
     my ($self,$text) = @_;
 
     $self->_entity($text, 'text');
+
+    return;
 }
 
 sub _entity {
@@ -191,24 +194,29 @@ sub _entity {
 
         if ( $match eq '' ) {
             $self->gripe( $type . '-use-entity', char => '&', entity => '&amp;' );
-        } elsif ( $match !~ m/;$/ ) {
+        }
+        elsif ( $match !~ m/;$/ ) {
             if ( exists $self->{_entity_lookup}->{$match}
                  || $match =~ m/^#(\d+)$/ || $match =~ m/^#x[\dA-F]+$/i) {
                 $self->gripe( $type . '-unclosed-entity', entity => "&$match;" );
-            } else {
+            }
+            else {
                 $self->gripe( $type . '-unknown-entity', entity => "&$match" );
             }
-        } elsif ( $match =~ m/^#(\d+);$/ ) {
+        }
+        elsif ( $match =~ m/^#(\d+);$/ ) {
             if ( $1 > 65536 ) {
                 $self->gripe( $type . '-invalid-entity', entity => "&$match" );
             }
-        } elsif ( $match =~ m/^#x([\dA-F]+);$/i ) {
+        }
+        elsif ( $match =~ m/^#x([\dA-F]+);$/i ) {
             if ( length($1) > 4 ) {
                 $self->gripe( $type . '-invalid-entity', entity => "&$match" );
             }
-        } else {
+        }
+        else {
             $match =~ s/;$//;
-            unless ( exists $self->{_entity_lookup}->{$match} ) {
+            if ( !exists $self->{_entity_lookup}->{$match} ) {
                 $self->gripe( $type . '-unknown-entity', entity => "&$match;" );
             }
         }
@@ -278,8 +286,8 @@ sub _normalize_value {
     my $what = shift;
 
     $what = _trim( $what );
-    return 1 if $what =~ /^(?:1|on|true)$/;
-    return 0 if $what =~ /^(?:0|off|false)$/;
+    return 1 if $what eq '1' || $what eq 'on'  || $what eq 'true';
+    return 0 if $what eq '0' || $what eq 'off' || $what eq 'false';
     return undef;
 }
 
@@ -290,7 +298,7 @@ sub _trim {
     return $_[0];
 }
 
-sub _end {
+sub _end {  ## no critic ( Subroutines::ProhibitManyArgs ) I have no choice in what these args are.
     my ($self,$tag,$line,$column,$tokenpos,@attr) = @_;
 
     $self->{_line} = $line;
@@ -373,7 +381,7 @@ sub _in_context {
 }
 
 # Overridden tag-specific stuff
-sub _start_img {
+sub _start_img {    ## no critic ( Subroutines::ProhibitUnusedPrivateSubroutines )  # Called by parser based on tag name.
     my ($self,$tag,%attr) = @_;
 
     my ($h,$w,$src) = @attr{qw( height width src )};
@@ -390,7 +398,7 @@ sub _start_img {
     return;
 }
 
-sub _start_input {
+sub _start_input {  ## no critic ( Subroutines::ProhibitUnusedPrivateSubroutines )  # Called by parser based on tag name.
     my ($self,$tag,%attr) = @_;
 
     my ($type,$alt) = @attr{qw( type alt )};
